# ninjalib is a data science library
#
# import ninjalib
# # new_data = ninjalib.ninjalib(data<nth dimensions list>).flatten_list()
# new_data = ninjalib.ninjalib(data<nth dimensions tuple>).flatten_tuple()
# new_data = ninjalib.ninjalib(focal_length<float>,x<float>,y<float>,z<float>).project()
# new_data = ninjalib.ninjalib(data<2D list of x,y,z coordinates>,axis<string>,angle<float>).project()
# new_data = ninjalib.ninjalib(data<int>).varint()
# 
# 
# Notes:
# project and rotate camera are for 3D rendering on a 2D plane
# varint is for Minecraft Java
